.e-site-editor__content_container {
	flex-direction: column;
	min-height: 100%;
	flex-wrap: nowrap;
}

.e-site-editor__content_container_main {
	flex: 1;
}

.e-site-editor__content_container_secondary {
	margin: 0 auto;
	padding-top: spacing(44);
}
