.site-editor__preview-iframe {
	height: 50vh;
	position: relative;

	&__iframe {
		top: 0;
		left: 0;
		position: absolute;
		border: none;
		transform-origin: 0 0;
		height: 100%;
	}

	&--header, &--footer{
		height: 15vh;
	}
}
