/*! elementor-pro - v3.5.2 - 28-11-2021 */
:root {
  --color-box-shadow-color: rgba(0, 0, 0, 0.05); }

.eps-theme-dark {
  --color-box-shadow-color: rgba(0, 0, 0, 0.1); }

:root {
  --eps-meta-icon-color: #c2cbd2; }

.eps-theme-dark {
  --eps-meta-icon-color: #b4b5b7; }

.e-site-template__meta-data {
  -webkit-margin-start: 0.625rem;
          margin-inline-start: 0.625rem;
  overflow: hidden;
  -o-text-overflow: ellipsis;
     text-overflow: ellipsis;
  white-space: nowrap;
  font-size: 0.6875rem; }
  .e-site-template__meta-data:last-of-type {
    -webkit-margin-end: auto;
            margin-inline-end: auto; }
  .e-site-template__meta-data:first-of-type {
    -webkit-margin-start: 1rem;
            margin-inline-start: 1rem; }
  .e-site-template__meta-data .eps-icon {
    -webkit-margin-end: 0.3125rem;
            margin-inline-end: 0.3125rem;
    color: var(--eps-meta-icon-color);
    font-size: 0.8125rem; }

.e-site-template__placeholder .eps-card__image {
  -webkit-filter: var(--placeholder-filter, none);
          filter: var(--placeholder-filter, none); }

.e-site-template__overlay-preview {
  padding-top: calc(var(--card-image-aspect-ratio, 95.6%) - 1.875rem);
  position: relative; }
  .e-site-template__overlay-preview-button {
    font-weight: bold;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
        flex-wrap: wrap;
    height: 1.875rem;
    width: 100%;
    background-color: var(--card-background-color-hover);
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    padding-top: 0.625rem;
    line-height: 1.25rem;
    --button-background-color: var(--card-headline-color); }
    .e-site-template__overlay-preview-button::before {
      content: '';
      position: absolute;
      display: block;
      width: 100%;
      top: 0;
      left: 0;
      padding-top: calc(var(--card-image-aspect-ratio, 95.6%) - 1.875rem); }
    .e-site-template__overlay-preview-button > :not(:first-child) {
      -webkit-margin-start: 0.3125rem;
              margin-inline-start: 0.3125rem; }

.e-site-template__edit-btn {
  -webkit-margin-end: 1.25rem;
          margin-inline-end: 1.25rem; }
  .e-site-template__edit-btn .eps-icon {
    -webkit-margin-end: 0.3125rem;
            margin-inline-end: 0.3125rem; }

.e-site-template__instances .eps-icon {
  -webkit-margin-end: 0.3125rem;
          margin-inline-end: 0.3125rem;
  color: var(--eps-meta-icon-color);
  font-size: 0.8125rem; }

.e-site-template__instances-list {
  overflow: hidden;
  -o-text-overflow: ellipsis;
     text-overflow: ellipsis;
  white-space: nowrap; }

.e-site-template__edit-conditions {
  -webkit-margin-start: 1rem;
          margin-inline-start: 1rem;
  color: #58d0f5;
  text-decoration: underline;
  font-style: italic; }

.e-site-template--extended .eps-card__figure {
  overflow: auto; }

.e-site-template--extended .eps-card__headline {
  -webkit-box-flex: 0;
      -ms-flex-positive: 0;
          flex-grow: 0; }

.e-site-template--wide {
  --card-image-aspect-ratio: calc(100% * 0.1235); }

.eps-add-new__overlay {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  opacity: 1;
  --card-image-overlay-background-color: transparent; }

.e-site-editor__templates .page-header {
  margin-bottom: 0.625rem; }

.e-site-editor__templates .eps-separator {
  margin-bottom: 2.75rem; }

:root {
  --e-site-editor-conditions-row-controls-background: #fff;
  --e-site-editor-input-wrapper-border-color: #f1f3f5;
  --e-site-editor-input-wrapper-select-color: #556068;
  --e-site-editor-add-button-background-color: #a4afb7;
  --e-site-editor-add-button-color-hover-background-color: #6d7882;
  --e-site-editor-input-wrapper-condition-include-background-color:
	#a4afb7;
  --e-site-editor-input-wrapper-condition-exclude-background-color:
	#c2cbd2;
  --e-site-editor-input-select2-search-field-color: #495157
; }

.eps-theme-dark {
  --select2-selection-background-color: tints(600);
  --e-site-editor-conditions-row-controls-background: #404349;
  --e-site-editor-input-wrapper-border-color: #404349;
  --e-site-editor-input-wrapper-select-color: #b4b5b7;
  --e-site-editor-add-button-background-color: #4c4f56;
  --e-site-editor-add-button-color-hover-background-color: #404349;
  --e-site-editor-input-wrapper-condition-include-background-color:
			#404349;
  --e-site-editor-input-wrapper-condition-exclude-background-color:
			#404349;
  --e-site-editor-input-select2-search-field-color: #fff

; }

.e-site-editor-conditions__header {
  text-align: center; }

.e-site-editor-conditions__header-image {
  display: block;
  margin: 0 auto 2.75rem;
  width: 4.375rem; }

.e-site-editor-conditions__rows {
  margin: 2.75rem auto;
  max-width: 43.75rem; }

.e-site-editor-conditions__row {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  margin-top: 0.75rem; }

.e-site-editor-conditions__remove-condition {
  color: #c2cbd2;
  font-size: 1.125rem;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }

.e-site-editor-conditions__row-controls {
  overflow: hidden;
  margin-left: 0.625rem;
  background-color: var(--e-site-editor-conditions-row-controls-background);
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  -webkit-box-shadow: 0 3px 6px var(--color-box-shadow-color);
          box-shadow: 0 3px 6px var(--color-box-shadow-color);
  border-radius: 0.1875rem; }
  .e-site-editor-conditions__row-controls--error {
    border: 1px solid #b01b1b; }

.e-site-editor-conditions__conflict {
  text-align: center;
  margin-top: 0.3125rem;
  color: #b01b1b; }

.e-site-editor-conditions__row-controls-inner {
  width: 100%;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }
  .e-site-editor-conditions__row-controls-inner div {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1; }

.e-site-editor-conditions__add-button-container {
  text-align: center; }

.e-site-editor-conditions__add-button {
  margin-top: 2.75rem;
  background-color: var(--e-site-editor-add-button-background-color);
  color: #fff;
  text-transform: uppercase; }
  .e-site-editor-conditions__add-button:hover {
    background-color: var(--e-site-editor-add-button-color-hover-background-color);
    color: #fff; }

.e-site-editor-conditions__footer {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end;
  position: absolute;
  bottom: 0;
  right: 0;
  left: 0;
  padding: 0.5rem;
  border-top: 1px solid var(--hr-color); }

.e-site-editor-conditions__input-wrapper {
  position: relative;
  border-right: 1px solid;
  border-color: var(--e-site-editor-input-wrapper-border-color); }
  .e-site-editor-conditions__input-wrapper:first-child {
    border: none; }
  .e-site-editor-conditions__input-wrapper select {
    -moz-appearance: none;
         appearance: none;
    -webkit-appearance: none;
    font-size: 0.75rem;
    height: 2.5rem;
    border-width: 0;
    padding: 0 0.625rem;
    width: 100%;
    position: relative;
    color: var(--e-site-editor-input-wrapper-select-color);
    outline: none;
    background: transparent; }
  .e-site-editor-conditions__input-wrapper:after {
    font-family: eicons;
    content: '\e8ad';
    font-size: 0.75rem;
    pointer-events: none;
    position: absolute;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    left: 0.625rem; }
  .e-site-editor-conditions__input-wrapper .select2-container--default .select2-selection--single {
    border: none;
    line-height: 2.5rem; }
  .e-site-editor-conditions__input-wrapper .select2-container--default .select2-selection--single .select2-selection__rendered {
    line-height: 2.5rem;
    font-size: 0.75rem; }
  .e-site-editor-conditions__input-wrapper .select2-selection {
    outline: none;
    background: transparent;
    height: 2.5rem; }
  .e-site-editor-conditions__input-wrapper .select2-selection__arrow {
    display: none; }

.e-site-editor-conditions__input-wrapper--condition-type {
  position: relative; }
  .e-site-editor-conditions__input-wrapper--condition-type:before {
    font-family: eicons;
    position: absolute;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    right: 0.75rem;
    font-size: 0.9375rem;
    color: #fff;
    pointer-events: none;
    z-index: 1000; }
  .e-site-editor-conditions__input-wrapper--condition-type:after {
    color: #fff; }
  .e-site-editor-conditions__input-wrapper--condition-type select {
    text-transform: uppercase;
    padding-right: 2.125rem;
    width: 7.5rem;
    font-size: 0.75rem;
    color: #fff; }
  .e-site-editor-conditions__input-wrapper--condition-type[data-elementor-condition-type="include"]:before {
    content: '\e8cc'; }
  .e-site-editor-conditions__input-wrapper--condition-type[data-elementor-condition-type="include"] select {
    background-color: var(--e-site-editor-input-wrapper-condition-include-background-color); }
  .e-site-editor-conditions__input-wrapper--condition-type[data-elementor-condition-type="exclude"]:before {
    content: '\e8cd'; }
  .e-site-editor-conditions__input-wrapper--condition-type[data-elementor-condition-type="exclude"] select {
    background-color: var(--e-site-editor-input-wrapper-condition-exclude-background-color); }

.select2-search__field {
  background-color: transparent;
  color: var(--e-site-editor-input-select2-search-field-color); }

.eps-back-button {
  font-size: 14px;
  margin-bottom: 1.5rem; }
  .eps-back-button .eps-icon {
    -webkit-transform: rotate(180deg);
        -ms-transform: rotate(180deg);
            transform: rotate(180deg); }

:root {
  --indicator-bullet-border-color: #fff; }

.eps-theme-dark {
  --indicator-bullet-border-color: #4c4f56; }

.eps-indicator-bullet {
  display: block;
  -ms-flex-negative: 0;
      flex-shrink: 0;
  width: 0.75rem;
  height: 0.75rem;
  -webkit-box-shadow: 0 2px 3px 1px var(--color-box-shadow-color);
          box-shadow: 0 2px 3px 1px var(--color-box-shadow-color);
  background-color: #d5dadf;
  border: 2px solid var(--indicator-bullet-border-color);
  border-radius: 100%;
  -webkit-margin-end: 0.625rem;
          margin-inline-end: 0.625rem; }
  .eps-indicator-bullet--active {
    background-color: #39b54a; }

.site-editor__preview-iframe {
  height: 50vh;
  position: relative; }
  .site-editor__preview-iframe__iframe {
    top: 0;
    left: 0;
    position: absolute;
    border: none;
    -webkit-transform-origin: 0 0;
        -ms-transform-origin: 0 0;
            transform-origin: 0 0;
    height: 100%; }
  .site-editor__preview-iframe--header, .site-editor__preview-iframe--footer {
    height: 15vh; }

.e-site-editor__content_container {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  min-height: 100%;
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }

.e-site-editor__content_container_main {
  -webkit-box-flex: 1;
      -ms-flex: 1;
          flex: 1; }

.e-site-editor__content_container_secondary {
  margin: 0 auto;
  padding-top: 2.75rem; }
/*# sourceMappingURL=app-rtl.css.map */